==> dl.php?src=linea21_1_0.zip: linea21/news/sup.php <==
<?php
//////////// Check Inclusion de pages ////////////
if (!function_exists('AuthenthificationProcess')){
	include_once("../lib/lib_common.php");
	ReloadIndex('admin');
}
////////////



if(isset($_POST['id']))	$id=$_POST['id'];
if(isset($_GET['id']))	$id=$_GET['id'];
$link_det=$rub_link."&amp;todo=det&amp;id=".$id; 


if(isset($_POST['valider'])) {
	$news_object = new news;
	$link_confirm="confirm.php?rub=".$rub."&todo=".$todo;
	$result=$news_object->DeleteNews($id, $sql_object);
	if($result) header("Location: ".$link_confirm);
	else  system_error();
}

$requete= SQL_getNewsTitle($id);
$result=$sql_object->DBSelect($requete);
$news_title=FormatText($result[0]['news_title']);
$news_owner=FormatText($result[0]['news_posted_by']);

//////////// Check Droits utilisateur ////////////
if (!HaveRight('news')) ReloadIndex('admin');
if (GetSessionElement('id')!=$news_owner && !IsSuperAdmin()) ReloadIndex('admin');
////////////
?>

<div id="chemin">
	<ul>
		<li>
			<a href="index.php"><? echo $GLOBALS['lang']['way']['home']; ?></a>
		</li>
		<li>
			<a href="<?php echo $rub_link; ?>"><? echo $GLOBALS['lang']['menu']['theme']; ?></a>
		</li>
		<li>
			<span><? echo formatNavTitle($GLOBALS['lang']['news']['sup']." : ". $news_title); ?></span>
		</li>
	</ul>
</div>
<!--end barre haute -->
<?php
include_once("quickicons.php");
?>
<div class="contentcontainer">
<?php
include_once($dir."/menurub.php");
?>
<div id="content">
<? echo "<h2>". formatTitleh2($news_title)."</h2>"; ?>
<form id="suptheme" action="<?php echo $_SERVER['SCRIPT_NAME']; ?>" method="post">
<p class="info"><?php echo $GLOBALS['lang']['divers']['sup_confirm']; ?></p>
<div>
<input name="id" type="hidden" value="<?php echo $id; ?>" />
<input name="rub" type="hidden" value="<?php echo $rub; ?>" id="rub" />
<input name="todo" type="hidden" value="<?php echo $todo; ?>" id="todo" />
<?php echo cancel_button('javascript:history.go(-1);'); ?>
<input name="valider" type="submit" value="<? echo $GLOBALS['lang']['btn']['valid']; ?>" class="button" id="valider" />
</div>
</form>
</div>
<?php include_once($dir."/help.php"); ?>
</div>

==> dl.php?src=linea21_1_3_1.zip: linea21/news/sup.php <==
<?php
/**
 * @package linea21.modules
 * @subpackage news
 * @author linea21 <info@linea21.com>
 * @version $id SVN
 * @access public
 * @license http://opensource.org/licenses/gpl-3.0.html
 */

//////////// Check Inclusion de pages ////////////
if (!function_exists('AuthenthificationProcess')){
	include_once("../lib/lib_common.php");
	ReloadIndex('admin');
}
////////////



if(isset($_POST['id']))	$id=$_POST['id'];
if(isset($_GET['id']))	$id=$_GET['id'];
$link_det=$rub_link."&amp;todo=det&amp;id=".$id; 


if(isset($_POST['valider'])) {
	$news_object = new news;
	$link_confirm="confirm.php?rub=".$rub."&todo=".$todo;
	$result=$news_object->DeleteNews($id, $sql_object);
	if($result) header("Location: ".$link_confirm);
	else  system_error();
}

$requete= SQL_getNewsTitle($id);
$result=$sql_object->DBSelect($requete);
$news_title=FormatText($result[0]['news_title']);
$news_owner=FormatText($result[0]['news_posted_by']);

//////////// Check Droits utilisateur ////////////
if (!HaveRight('news')) ReloadIndex('admin');
if (GetSessionElement('id')!=$news_owner && !IsSuperAdmin()) ReloadIndex('admin');
////////////
?>

<div id="chemin">
	<ul>
		<li>
			<a href="index.php" class="chemin_home"><? echo _t('way','home'); ?></a>
		</li>
		<li>
			   <a href="<?php echo $rub_link; ?>" id="chemin_<? echo $rub; ?>" class="chemin_rub"><? echo _t('menu','news'); ?></a>
		</li>
		<li>
			<span><? echo formatNavTitle(_t('news','sup')." : ". $news_title); ?></span>
		</li>
	</ul>
</div>
<!--end barre haute -->
<?php
include_once(THEME_ADMIN_PATH."quickicons.php");
?>
<div class="contentcontainer">
<?php
include_once($dir."/menurub.php");
?>
<div id="content">
<? echo "<h2>". formatTitleh2($news_title)."</h2>"; ?>
<form id="suptheme" action="<?php echo $_SERVER['SCRIPT_NAME']; ?>" method="post">
<p class="info"><?php echo _t('divers','sup_confirm'); ?></p>
<div>
<input name="id" type="hidden" value="<?php echo $id; ?>" />
<input name="rub" type="hidden" value="<?php echo $rub; ?>" id="rub" />
<input name="todo" type="hidden" value="<?php echo $todo; ?>" id="todo" />
<?php echo cancel_button('javascript:history.go(-1);'); ?>
<input name="valider" type="submit" value="<? echo _t('btn','valid'); ?>" class="button" id="valider" />
</div>
</form>
</div>
<?php include_once($dir."/help.php"); ?>
</div>
